"""
This module is used to provide the necessary classes and exceptions
for the authentication and authorization of users.
"""
from user_vpetrov.schemas import User
from user_vpetrov.schemas import Admin as AdminUser
from .exceptions import AuthorizationException
from .middlewares import require_admin_user, require_user

from .schemas import Token, TokenData, ValidationCode

__all__ = [
    "User",
    "AdminUser",
    "AuthorizationException",
    "require_admin_user",
    "require_user",
    "Token",
    "TokenData",
    "ValidationCode",
]



"""
Schemas for the winners_app app
"""
from datetime import datetime, timedelta
from pydantic import BaseModel, Field, EmailStr


class Token(BaseModel):
    """
    Base schema for Tokens.
    """
    access_token: str = Field(..., description="The access Bearer token")


class TokenData(BaseModel):
    """
    Base schema for TokenData.
    """
    email: EmailStr
    password: str
    exp: datetime = Field(
        default_factory=lambda: datetime.now() + timedelta(minutes=43200),
    )


class ValidationCode(BaseModel):
    """
    Base schema for Validation.
    """
    code: str = Field(
        ..., description="The validation code", max_length=6, min_length=6)



"""
Exceptions for the winners app.
"""
from fastapi import HTTPException
from pydantic import BaseModel


class AuthorizationException(HTTPException):
    """
    Exception for authorization errors.
    """
    class AuthorizationErrorSchema(BaseModel):
        """
        Schema for the AuthorizationError model.
        """
        detail: str = "You are not authorized to perform this action"

    def __init__(self):
        schema_instance = self.AuthorizationErrorSchema()
        super().__init__(
            status_code=401,
            detail=schema_instance.detail
            )



"""
Setup file for auth_utils package
"""
from setuptools import setup, find_packages

setup(
    name='auth_vpetrov',
    version='0.3.4',
    packages=find_packages(),
    install_requires=[
        'fastapi',
        'pydantic',
        'user-vpetrov',
        'typing',
        'requests',
    ],
)
